@@ -1,26 +1,32 @@
 /*
-Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
-
-The MySQL Connector/C++ is licensed under the terms of the GPLv2
-<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-MySQL Connectors. There are special exceptions to the terms and
-conditions of the GPLv2 as it is applied to this software, see the
-FLOSS License Exception
-<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published
-by the Free Software Foundation; version 2 of the License.
-
-This program is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0, as
+ * published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an
+ * additional permission to link the program and your derivative works
+ * with the separately licensed software that they have included with
+ * MySQL.
+ *
+ * Without limiting anything contained in the foregoing, this file,
+ * which is part of MySQL Connector/C++, is also subject to the
+ * Universal FOSS Exception, version 1.0, a copy of which can be found at
+ * http://oss.oracle.com/licenses/universal-foss-exception.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License, version 2.0, for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+ */
 
 
 
@@ -30,6 +36,7 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 #include "nativeapi/mysql_private_iface.h"
 #include <cppconn/config.h>
 #include <cppconn/sqlstring.h>
+#include <cppconn/exception.h>
 #include <boost/shared_ptr.hpp>
 
 
@@ -141,16 +148,30 @@ char * utf8_strup(const char * const src, size_t srclen);
 
 long double strtold(const char *nptr, char **endptr);
 
+/*
+  Generic string to number conversion function template.
+
+  Retrurns numeric value after converting given string in a given base,
+  which should be either 10, 16 or 8. Throws error if the whole string
+  could not be converted to a number.
+
+  Unlike strtod() and friends, this function does not depend on the current
+  locale setting but always uses the "C" locale (so that, e.g., decimal point
+  character is always '.').
+*/
+
+long double strtonum(const std::string &str, int radix = 10);
+
 typedef struct st_our_charset
 {
-	unsigned int	nr;
-	const char		*name;
-	const char		*collation;
-	unsigned int	char_minlen;
-	unsigned int	char_maxlen;
-	const char		*comment;
-	unsigned int 	(*mb_charlen)(unsigned int c);
-	unsigned int 	(*mb_valid)(const char *start, const char *end);
+  unsigned int	nr;
+  const char		*name;
+  const char		*collation;
+  unsigned int	char_minlen;
+  unsigned int	char_maxlen;
+  const char		*comment;
+  unsigned int 	(*mb_charlen)(unsigned int c);
+  unsigned int 	(*mb_valid)(const char *start, const char *end);
 } OUR_CHARSET;
 
 const OUR_CHARSET * find_charset(unsigned int charsetnr);
