@@ -1,26 +1,32 @@
 /*
-Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
-
-The MySQL Connector/C++ is licensed under the terms of the GPLv2
-<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-MySQL Connectors. There are special exceptions to the terms and
-conditions of the GPLv2 as it is applied to this software, see the
-FLOSS License Exception
-<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published
-by the Free Software Foundation; version 2 of the License.
-
-This program is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0, as
+ * published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an
+ * additional permission to link the program and your derivative works
+ * with the separately licensed software that they have included with
+ * MySQL.
+ *
+ * Without limiting anything contained in the foregoing, this file,
+ * which is part of MySQL Connector/C++, is also subject to the
+ * Universal FOSS Exception, version 1.0, a copy of which can be found at
+ * http://oss.oracle.com/licenses/universal-foss-exception.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License, version 2.0, for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+ */
 
 
 #include "bugs.h"
@@ -533,7 +539,7 @@ void bugs::bug71606()
 void bugs::bug72700()
 {
   logMsg("bugs::bug72700");
-  ASSERT(stmt->execute("select astext(geomfromtext('point(10 10)'))"));
+  ASSERT(stmt->execute("select ST_AsText(ST_GeomFromText('point(10 10)'))"));
 
   try
   {
@@ -570,9 +576,9 @@ void bugs::bug72700()
 
 void bugs::bug66871()
 {
-  sql::Connection *con;
-  sql::Statement *stmt;
-  sql::ResultSet *res;
+  sql::Connection *con = NULL;
+  sql::Statement *stmt = NULL;
+  sql::ResultSet *res = NULL;
 
   logMsg("bugs::bug66871");
   try
@@ -798,7 +804,9 @@ void bugs::bug21066575()
         std::stringstream ss;
         ss << "id = " << res->getInt(1);
         ss << std::endl;
-        ss << "f1 = " << res->getString(2);
+        std::string out = res->getString(2);
+        ASSERT_EQUALS(1024000UL, static_cast<uint64_t>(out.length()));
+        ss << "f1 = " << out;
         logMsg(ss.str().c_str());
       }
       //Detect if process frees ResultSet resources.
